@@ -1,9 +1,11 @@
 pub mod cargo_cmds;
-pub use cargo_cmds::ToolChain;
 use cargo_cmds::*;
 mod executor;
 pub use executor::Executor;
+mod toolchain;
+pub use toolchain::ToolChain;
 mod utils;
+
 use std::{
     io::{self, Write},
     process::{Child, ExitStatus},
@@ -35,12 +37,20 @@ pub struct Repl {
 }
 
 impl Repl {
-    pub fn new(toolchain: ToolChain, executor: Executor) -> Result<Self> {
-        cargo_new(toolchain)?;
+    pub fn new(toolchain: ToolChain) -> Result<Self> {
+        Self::new_with_executor(toolchain, Executor::Sync)
+    }
+
+    pub fn new_with_executor(toolchain: ToolChain, executor: Executor) -> Result<Self> {
+        cargo_new()?;
         // check for required dependencies (in case of async)
         if let Some(dependecy) = executor.dependecy() {
+            // needs to be sync
+            // repl::new(Tokio)
+            // repl.eval(5); // cargo-edit may not have written to Cargo.toml yet
             cargo_add_sync(&dependecy)?;
         }
+        cargo_build(toolchain)?;
 
         Ok(Self {
             body: vec![
@@ -112,7 +122,7 @@ impl Repl {
     }
 
     pub fn reset(&mut self) -> Result<()> {
-        *self = Self::new(self.toolchain, self.executor)?;
+        *self = Self::new_with_executor(self.toolchain, self.executor)?;
         Ok(())
     }
 
